#ifndef __displaytiles_h
#define __displaytiles_h


class TimeTile
{
	private:
		byte _color;
		byte _line;
		int  _count;
		byte _state;
		#define TIMETILE_STATE_ON 	0
		#define TIMETILE_STATE_SETH 1
		#define TIMETILE_STATE_SETM	2
		#define TIMETILE_STATE_SETS	3
		void _show(int h, int m, int s, byte ch, byte cm, byte cs);
	public:
		TimeTile();
		void init();
		void show();
		void tick();
		bool sendKey(int keyCode);
};


class DateTile
{
	private:
		byte _color;
		byte _line;
		int  _count;
		byte _state;
		#define DATETILE_STATE_ON	0
		#define DATETILE_STATE_SETD	1
		#define DATETILE_STATE_SETM	2
		#define DATETILE_STATE_SETY	3
	public:
		DateTile();
		void init();
		void show();
		void tick();
		bool sendKey(int keyCode);
		void startSetting(); // SET button pushed at seconds
};


class TempTile
{
	private:
		byte _line;
	public:
		TempTile();
		void init();
		void show();
		void tick();
};


class CountdownTile
{
	#define COUNTDOWN_EEPROM_ADDR 0x22
	#define COUNTDOWN_EEPROM_SIGN 0x66
	private:
		byte _line;
		byte minutes;
		byte seconds;
		int currSeconds;
		unsigned long millisStart;
		byte _state;
		#define COUNTDOWN_STATE_OFF		0
		#define COUNTDOWN_STATE_ON		1
		#define COUNTDOWN_STATE_WAITING	2
		#define COUNTDOWN_STATE_RUNNING	3
		#define COUNTDOWN_STATE_SETMIN	4
		#define COUNTDOWN_STATE_SETSEC	5
		void _ReadFromEprom();
		void _WriteToEprom(byte m, byte s);
		void _startCountDown();
		void _doCountDown();
                void _show(byte minColor, byte secColor);
	public:
		CountdownTile();
		void init();
		void show();
		void tick();
		bool sendKey(int keyCode);
};

#define KEYCODE_TIMER	0x01
#define KEYCODE_SET		0x02
#define KEYCODE_PLUS	0x04
#define KEYCODE_MINUS	0x08

class DisplayManager
{
	private:
		TimeTile		time;
		DateTile		date;
		TempTile		temperature;
		CountdownTile	countdown;
		byte			intensity;
		byte			owner;
		#define KEYOWNER_MYSELF 0
		#define KEYOWNER_TIME	1
		#define KEYOWNER_DATE	2
		#define KEYOWNER_TIMER	3
		#define KEYOWNER_MAX	3

	public:
		DisplayManager();
		void init();
		void show();
		void tick();
		void sendKey(int keyCode);
};

extern DisplayManager	displayManager;

#endif